@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -25,19 +25,6 @@
 #include <QObject>
 #include <QStringList>
 
-class ClientSocket;
-
-class InputReader : public QObject
-{
-    Q_OBJECT
-
-public:
-    void readInput();
-
-signals:
-    void inputRead(const QByteArray &input);
-};
-
 /**
  * Application client.
  *
@@ -46,7 +33,7 @@ signals:
  * Also the received message is printed on standard output (if exit code is
  * zero) or standard error output.
  */
-class ClipboardClient : public QObject, public App
+class ClipboardClient final : public QObject, public App
 {
     Q_OBJECT
 
@@ -54,33 +41,16 @@ public:
     ClipboardClient(
             int &argc, char **argv, const QStringList &arguments, const QString &sessionName);
 
-    void setInput(const QByteArray &input);
-
-    void sendInput();
-
-    void exit(int exitCode) override;
-
-    void startInputReader();
-
 signals:
     void functionCallResultReceived(const QByteArray &returnValue);
-    void inputReceived(const QByteArray &input);
     void inputDialogFinished(const QByteArray &data);
-    void stopEventLoops();
-    void scriptableFinished();
 
 private:
     void onMessageReceived(const QByteArray &data, int messageCode);
     void onDisconnected();
     void onConnectionFailed();
 
-    void abortInputReader();
-    bool isInputReaderFinished() const;
     void start(const QStringList &arguments);
-
-    ClientSocket *m_socket = nullptr;
-    QThread *m_inputReaderThread;
-    QByteArray m_input;
 };
 
 #endif // CLIPBOARDCLIENT_H
