@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -27,7 +27,6 @@
 #include "common/textdata.h"
 #include "item/serialize.h"
 #include "platform/platformclipboard.h"
-#include "platform/platformwindow.h"
 
 #include <QApplication>
 
@@ -65,14 +64,14 @@ bool isClipboardDataHidden(const QVariantMap &data)
 } // namespace
 
 ClipboardMonitor::ClipboardMonitor(const QStringList &formats)
-    : m_clipboard(createPlatformNativeInterface()->clipboard())
+    : m_clipboard(platformNativeInterface()->clipboard())
     , m_formats(formats)
 {
     const AppConfig config;
     m_storeClipboard = config.option<Config::check_clipboard>();
     m_clipboardTab = config.option<Config::clipboard_tab>();
 
-    m_clipboard->setFormats(formats);
+    m_clipboard->startMonitoring(formats);
     connect( m_clipboard.get(), &PlatformClipboard::changed,
              this, &ClipboardMonitor::onClipboardChanged );
 
@@ -96,6 +95,7 @@ void ClipboardMonitor::onClipboardChanged(ClipboardMode mode)
     if ( hasSameData(data, *clipboardData) ) {
         COPYQ_LOG( QString("Ignoring unchanged %1")
                    .arg(mode == ClipboardMode::Clipboard ? "clipboard" : "selection") );
+        emit clipboardUnchanged(data);
         return;
     }
 
@@ -114,10 +114,9 @@ void ClipboardMonitor::onClipboardChanged(ClipboardMode mode)
 
     // add window title of clipboard owner
     if ( !data.contains(mimeOwner) && !data.contains(mimeWindowTitle) ) {
-        PlatformPtr platform = createPlatformNativeInterface();
-        PlatformWindowPtr currentWindow = platform->getCurrentWindow();
-        if (currentWindow)
-            data.insert( mimeWindowTitle, currentWindow->getTitle().toUtf8() );
+        const QByteArray windowTitle = m_clipboard->clipboardOwner();
+        if ( !windowTitle.isEmpty() )
+            data.insert(mimeWindowTitle, windowTitle);
     }
 
 #ifdef HAS_MOUSE_SELECTIONS
