@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -32,7 +32,7 @@ enum class ClipboardOwnership {
     Hidden,
 };
 
-class ClipboardMonitor : public QObject
+class ClipboardMonitor final : public QObject
 {
     Q_OBJECT
 
@@ -41,6 +41,7 @@ public:
 
 signals:
     void clipboardChanged(const QVariantMap &data, ClipboardOwnership ownership);
+    void clipboardUnchanged(const QVariantMap &data);
     void synchronizeSelection(ClipboardMode sourceMode, const QString &text, uint targetTextHash);
 
 private:
