@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -307,11 +307,18 @@ bool Action::waitForFinished(int msecs)
     QPointer<QObject> self(this);
     QEventLoop loop;
     QTimer t;
-    connectProcessFinished(m_processes.back(), &loop, &QEventLoop::quit);
-    connect(&t, &QTimer::timeout, &loop, &QEventLoop::quit);
-    t.start(msecs);
+    connect(this, &Action::actionFinished, &loop, &QEventLoop::quit);
+    if (msecs >= 0) {
+        connect(&t, &QTimer::timeout, &loop, &QEventLoop::quit);
+        t.setSingleShot(true);
+        t.start(msecs);
+    }
     loop.exec(QEventLoop::ExcludeUserInputEvents);
 
+    // Loop stopped because application is exiting?
+    while ( self && isRunning() && (msecs < 0 || t.isActive()) )
+        QCoreApplication::processEvents(QEventLoop::WaitForMoreEvents, 10);
+
     return !self || !isRunning();
 }
 
