@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -31,12 +31,54 @@
 
 #include <QBuffer>
 #include <QListWidgetItem>
+#include <QMimeData>
 #include <QMovie>
 #include <QScrollBar>
 #include <QUrl>
 
+namespace {
+
 // Limit number of characters to load at once - performance reasons.
-static const int batchLoadCharacters = 4096;
+constexpr int batchLoadCharacters = 4096;
+constexpr int priorityHigh = 100;
+constexpr int priorityMedium = priorityHigh / 2;
+constexpr int priorityLow = priorityMedium / 2;
+constexpr int priorityLower = priorityLow / 2;
+constexpr int priorityLowest = 0;
+
+QVariant cloneClipboardData(const QString &format)
+{
+    const QMimeData *clipData = clipboardData();
+    if (!clipData)
+        return QVariant();
+
+    return cloneData(*clipData, QStringList(format)).value(format);
+}
+
+int formatSortPriority(const QString &format)
+{
+    if (format == mimeText)
+        return priorityHigh + 2;
+
+    if (format == mimeHtml)
+        return priorityHigh + 1;
+
+    if ( format.startsWith("text/") )
+        return priorityHigh;
+
+    if ( format.startsWith("application/") )
+        return priorityLow;
+
+    if ( format.contains("/x-") )
+        return priorityLower;
+
+    if ( format.isEmpty() || format[0].isUpper() )
+        return priorityLowest;
+
+    return priorityMedium;
+}
+
+} // namespace
 
 ClipboardDialog::ClipboardDialog(QWidget *parent)
     : QDialog(parent)
@@ -44,8 +86,13 @@ ClipboardDialog::ClipboardDialog(QWidget *parent)
     init();
 
     const QMimeData *clipData = clipboardData();
-    if (clipData)
-        setData( cloneData(*clipData) );
+    if (clipData) {
+        m_dataFromClipboard = true;
+        for (const auto &format : clipData->formats()) {
+            m_data.insert(format, QVariant());
+        }
+        setData(m_data);
+    }
 }
 
 ClipboardDialog::ClipboardDialog(
@@ -87,7 +134,11 @@ void ClipboardDialog::onListWidgetFormatsCurrentItemChanged(
     else
         ui->labelContent->setBuddy(ui->textEdit);
 
-    const QByteArray bytes = m_data.value(mime).toByteArray();
+    QVariant value = m_data.value(mime);
+    if ( m_dataFromClipboard && !value.isValid() )
+        value = m_data[mime] = cloneClipboardData(mime).toByteArray();
+
+    const QByteArray bytes = value.toByteArray();
 
     m_timerTextLoad.stop();
 
@@ -189,19 +240,17 @@ void ClipboardDialog::setData(const QVariantMap &data)
 {
     const QString currentFormat = ui->listWidgetFormats->currentIndex().data().toString();
     ui->listWidgetFormats->clear();
-    m_data.clear();
+    m_data = data;
 
-    // Show only data that can be displayed.
-    for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
-        const auto &mime = it.key();
-        const auto &bytes = it.value();
-        if ( bytes.canConvert<QByteArray>() ) {
-            m_data.insert(mime, bytes);
-            ui->listWidgetFormats->addItem(mime);
-            if (mime == currentFormat) {
-                ui->listWidgetFormats->setCurrentRow(
-                            ui->listWidgetFormats->count() - 1);
-            }
+    QStringList formats = data.keys();
+    std::sort( std::begin(formats), std::end(formats), [](const QString &lhs, const QString &rhs) {
+        return formatSortPriority(lhs) > formatSortPriority(rhs) || lhs < rhs;
+    } );
+    for (const QString &format : formats) {
+        ui->listWidgetFormats->addItem(format);
+        if (format == currentFormat) {
+            ui->listWidgetFormats->setCurrentRow(
+                        ui->listWidgetFormats->count() - 1);
         }
     }
 
