@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -35,7 +35,7 @@ class QAbstractButton;
 class QMenu;
 class QScrollArea;
 
-class ItemOrderList : public QWidget
+class ItemOrderList final : public QWidget
 {
     Q_OBJECT
 
