@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -46,7 +46,7 @@ namespace {
 
 bool findPluginDir(QDir *pluginsDir)
 {
-    return createPlatformNativeInterface()->findPluginDir(pluginsDir)
+    return platformNativeInterface()->findPluginDir(pluginsDir)
             && pluginsDir->isReadable();
 }
 
@@ -78,7 +78,7 @@ void trySetPixmap(QLabel *label, const QVariantMap &data, int height)
 
 
 /** Sort plugins by prioritized list of names. */
-class PluginSorter {
+class PluginSorter final {
 public:
     explicit PluginSorter(const QStringList &pluginNames) : m_order(pluginNames) {}
 
@@ -106,7 +106,7 @@ private:
     const QStringList &m_order;
 };
 
-class DummyItem : public QLabel, public ItemWidget {
+class DummyItem final : public QLabel, public ItemWidget {
 public:
     DummyItem(const QVariantMap &data, QWidget *parent, bool preview)
         : QLabel(parent)
@@ -139,11 +139,6 @@ public:
         m_data.remove(mimeItemNotes);
     }
 
-    QWidget *createEditor(QWidget *parent) const override
-    {
-        return m_hasText ? ItemWidget::createEditor(parent) : nullptr;
-    }
-
     void updateSize(QSize, int idealWidth) override
     {
         setFixedWidth(idealWidth);
@@ -167,7 +162,7 @@ private:
     QString m_imageFormat;
 };
 
-class DummySaver : public ItemSaverInterface
+class DummySaver final : public ItemSaverInterface
 {
 public:
     bool saveItems(const QString & /* tabName */, const QAbstractItemModel &model, QIODevice *file) override
@@ -176,7 +171,7 @@ public:
     }
 };
 
-class DummyLoader : public ItemLoaderInterface
+class DummyLoader final : public ItemLoaderInterface
 {
 public:
     QString id() const override { return QString(); }
@@ -364,6 +359,8 @@ void ItemFactory::setLoaderEnabled(const ItemLoaderPtr &loader, bool enabled)
             m_disabledLoaders.remove( m_disabledLoaders.indexOf(loader) );
         else
             m_disabledLoaders.append(loader);
+
+        loader->setEnabled(enabled);
     }
 }
 
@@ -445,6 +442,17 @@ QList<ItemScriptable*> ItemFactory::scriptableObjects() const
 
 QVector<Command> ItemFactory::commands() const
 {
+#ifdef HAS_TESTS
+    const QString id = qApp->property("CopyQ_test_id").toString();
+    if ( !id.isEmpty() ) {
+        for ( const auto &loader : enabledLoaders() ) {
+            if (loader->id() == id)
+                return loader->commands();
+        }
+        return QVector<Command>();
+    }
+#endif
+
     QVector<Command> commands;
 
     for ( const auto &loader : enabledLoaders() )
@@ -464,38 +472,6 @@ void ItemFactory::loaderChildDestroyed(QObject *obj)
     m_loaderChildren.remove(obj);
 }
 
-ItemWidget *ItemFactory::otherItemLoader(
-        const QVariantMap &data, ItemWidget *current, bool next, bool antialiasing)
-{
-    Q_ASSERT(current->widget() != nullptr);
-
-    auto w = current->widget();
-    auto currentLoader = m_loaderChildren.value(w);
-    if (!currentLoader)
-        return nullptr;
-
-
-    const ItemLoaderList loaders = enabledLoaders();
-
-    const int currentIndex = loaders.indexOf(currentLoader);
-    Q_ASSERT(currentIndex != -1);
-
-    const int size = loaders.size();
-    const int dir = next ? 1 : -1;
-    for (int i = currentIndex + dir; i != currentIndex; i = i + dir) {
-        if (i >= size)
-            i = i % size;
-        else if (i < 0)
-            i = size - 1;
-
-        ItemWidget *item = createItem(loaders[i], data, w->parentWidget(), antialiasing);
-        if (item != nullptr)
-            return item;
-    }
-
-    return nullptr;
-}
-
 bool ItemFactory::loadPlugins()
 {
 #ifdef COPYQ_PLUGIN_PREFIX
@@ -542,8 +518,8 @@ void ItemFactory::loadItemFactorySettings(QSettings *settings)
         for (const auto &name : settings->allKeys()) {
             s[name] = settings->value(name);
         }
-        loader->loadSettings(s);
         setLoaderEnabled( loader, settings->value("enabled", true).toBool() );
+        loader->loadSettings(s);
 
         settings->endGroup();
     }
@@ -555,6 +531,37 @@ void ItemFactory::loadItemFactorySettings(QSettings *settings)
     setPluginPriority(pluginPriority);
 }
 
+QObject *ItemFactory::createExternalEditor(const QModelIndex &index, const QVariantMap &data, QWidget *parent) const
+{
+    for ( auto &loader : enabledLoaders() ) {
+        QObject *editor = loader->createExternalEditor(index, data, parent);
+        if (editor != nullptr)
+            return editor;
+    }
+
+    return nullptr;
+}
+
+QVariantMap ItemFactory::data(const QModelIndex &index) const
+{
+    QVariantMap data = index.data(contentType::data).toMap();
+    for (auto &loader : enabledLoaders()) {
+        if ( !loader->data(&data, index) )
+            return QVariantMap();
+    }
+    return data;
+}
+
+bool ItemFactory::setData(const QVariantMap &data, const QModelIndex &index, QAbstractItemModel *model) const
+{
+    for (auto &loader : enabledLoaders()) {
+        if ( loader->setData(data, index, model) )
+            return true;
+    }
+
+    return model->setData(index, data, contentType::updateData);
+}
+
 ItemLoaderList ItemFactory::enabledLoaders() const
 {
     ItemLoaderList enabledLoaders;
