@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -27,6 +27,7 @@
 #include <QtPlugin>
 #include <QVariantMap>
 #include <QVector>
+#include <QWidget>
 
 #include <memory>
 
@@ -37,7 +38,6 @@ class QFont;
 class QModelIndex;
 class QPalette;
 class QRegExp;
-class QWidget;
 struct Command;
 
 class ItemLoaderInterface;
@@ -49,7 +49,7 @@ using ItemSaverPtr = std::shared_ptr<ItemSaverInterface>;
 class ItemScriptableFactoryInterface;
 using ItemScriptableFactoryPtr = std::shared_ptr<ItemScriptableFactoryInterface>;
 
-#define COPYQ_PLUGIN_ITEM_LOADER_ID "com.github.hluk.copyq.itemloader/3.7.3"
+#define COPYQ_PLUGIN_ITEM_LOADER_ID "com.github.hluk.copyq.itemloader/3.8.0"
 
 /**
  * Handles item in list.
@@ -72,44 +72,6 @@ public:
      */
     QWidget *widget() const { return m_widget; }
 
-    /**
-     * Create editor widget with given @a parent.
-     * Editor widget can have signals:
-     *   1. save(), to save data,
-     *   2. cancel(), if hasChanges() is true a dialog will pop-up asking user whether to save
-     *      changes, otherwise editor closes,
-     *   3. invalidate(), to close editor immediately.
-     */
-    virtual QWidget *createEditor(QWidget *parent) const;
-
-    /**
-     * Set data for editor widget.
-     */
-    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const;
-
-    /**
-     * Set data from editor widget to model.
-     */
-    virtual void setModelData(QWidget *editor, QAbstractItemModel *model,
-                              const QModelIndex &index) const;
-
-    /**
-     * Return true if data in editor were changed.
-     */
-    virtual bool hasChanges(QWidget *editor) const;
-
-    /**
-     * Create external editor for @a index.
-     *
-     * Default implementation returns nullptr.
-     *
-     * @param index  index for which the editor is opened
-     *
-     * @return Editor object -- see documentation for public signals and slots of ItemEditor class --
-     *         nullptr so default text editor is opened.
-     */
-    virtual QObject *createExternalEditor(const QModelIndex &index, QWidget *parent) const;
-
     /**
      * Size of widget needs to be updated (because maximum size chaged).
      */
@@ -169,7 +131,6 @@ private:
  */
 class ItemScriptable : public QObject
 {
-    Q_OBJECT
 public:
     /** Return scriptable object (nullptr before start() is called). */
     QObject *scriptable() const { return m_scriptable; }
@@ -353,6 +314,8 @@ public:
      */
     virtual QVariantMap applySettings() { return QVariantMap(); }
 
+    virtual void setEnabled(bool) {}
+
     /**
      * Load stored configuration values.
      */
@@ -431,6 +394,22 @@ public:
      */
     virtual QVector<Command> commands() const;
 
+    virtual bool data(QVariantMap *data, const QModelIndex &index) const;
+
+    virtual bool setData(const QVariantMap &data, const QModelIndex &index, QAbstractItemModel *model) const;
+
+    /**
+     * Create external editor for @a index.
+     *
+     * Default implementation returns nullptr.
+     *
+     * @param index  index for which the editor is opened
+     *
+     * @return Editor object -- see documentation for public signals and slots of ItemEditor class --
+     *         nullptr so default text editor is opened.
+     */
+    virtual QObject *createExternalEditor(const QModelIndex &index, const QVariantMap &data, QWidget *parent) const;
+
     ItemLoaderInterface(const ItemLoaderInterface &) = delete;
     ItemLoaderInterface &operator=(const ItemLoaderInterface &) = delete;
 };
