@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -28,13 +28,12 @@
 
 #include <memory>
 
-class X11PlatformClipboard : public DummyClipboard
+class X11PlatformClipboard final : public DummyClipboard
 {
-    Q_OBJECT
 public:
     X11PlatformClipboard();
 
-    void setFormats(const QStringList &formats) override;
+    void startMonitoring(const QStringList &formats) override;
 
     QVariantMap data(ClipboardMode mode, const QStringList &formats) const override;
 
@@ -53,12 +52,13 @@ private:
         QStringList formats;
         QByteArray newDataTimestamp;
         ClipboardMode mode;
+        bool changed = false;
     };
 
     void check();
     bool updateClipboardData(ClipboardData *clipboardData);
     void useNewClipboardData(ClipboardData *clipboardData);
-    void checkAgainLater(bool clipboardChanged);
+    void checkAgainLater(bool clipboardChanged, int interval);
 
     QTimer m_timerCheckAgain;
     int m_checkAgainIntervalMs = 0;
