@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -75,7 +75,7 @@ QDataStream &operator>>(QDataStream &in, ScriptablePath &path);
 QDataStream &operator<<(QDataStream &out, Qt::KeyboardModifiers value);
 QDataStream &operator>>(QDataStream &in, Qt::KeyboardModifiers &value);
 
-class ScriptableProxy : public QObject
+class ScriptableProxy final : public QObject
 {
     Q_OBJECT
 
@@ -195,8 +195,6 @@ public slots:
 
     int inputDialog(const NamedValueList &values);
 
-    void setUserValue(const QString &key, const QVariant &value);
-
     void setSelectedItemsData(const QString &mime, const QVariant &value);
 
     void filter(const QString &text);
@@ -211,6 +209,8 @@ public slots:
     QStringList screenNames();
 
     Qt::KeyboardModifiers queryKeyboardModifiers();
+    QPoint pointerPosition();
+    void setPointerPosition(int x, int y);
 
     QString pluginsPath();
     QString themesPath();
