@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -30,7 +30,7 @@
 #include <QTest>
 #include <QVariantMap>
 
-class PerformanceTimer {
+class PerformanceTimer final {
 public:
     PerformanceTimer() {
         m_timer.start();
@@ -66,8 +66,8 @@ do { \
 #define RUN(ARGUMENTS, STDOUT_EXPECTED) \
     TEST( m_test->runClient((Args() << ARGUMENTS), toByteArray(STDOUT_EXPECTED)) );
 
-#define RUN_WITH_INPUT(ARGUMENTS, STDOUT_EXPECTED, INPUT) \
-    TEST( m_test->runClient((Args() << ARGUMENTS), toByteArray(INPUT), toByteArray(STDOUT_EXPECTED)) );
+#define RUN_WITH_INPUT(ARGUMENTS, INPUT, STDOUT_EXPECTED) \
+    TEST( m_test->runClient((Args() << ARGUMENTS), toByteArray(STDOUT_EXPECTED), toByteArray(INPUT)) );
 
 #define RUN_EXPECT_ERROR(ARGUMENTS, EXIT_CODE) \
     TEST( m_test->runClientWithError((Args() << ARGUMENTS), (EXIT_CODE)) );
